changeset 9079:2cd83c854073 v7.4.1824

commit https://github.com/vim/vim/commit/36e0f7da9bc4a6ee8a7b17df503542a339e034c8 Author: Bram Moolenaar <Bram@vim.org> Date: Sun May 8 13:21:12 2016 +0200 patch 7.4.1824 Problem: When a job is no longer referenced and does not have an exit callback the process may hang around in defunc state. (Nicola) Solution: Call job_status() if the job is running and won't get freed because it might still be useful.
author Christian Brabandt <cb@256bit.org>
date Sun, 08 May 2016 13:30:07 +0200
parents ce97eee5a03f
children af3def158d85
files src/channel.c src/version.c
diffstat 2 files changed, 5 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -754,6 +754,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1824,
+/**/
     1823,
 /**/
     1822,
--- a/src/channel.c
+++ b/src/channel.c
@@ -4144,7 +4144,7 @@ free_unused_jobs_contents(int copyID, in
 	     * recurse into Lists, Dictionaries etc. */
 	    job_free_contents(job);
 	    did_free = TRUE;
-    }
+	}
     return did_free;
 }
 
@@ -4234,7 +4234,7 @@ job_stop_on_exit()
 }
 
 /*
  * Called once in a while: check if any jobs with an "exit_cb" have ended.
  */
     void
 job_check_ended(void)
@@ -4252,7 +4252,7 @@ job_check_ended(void)
 	for (job = first_job; job != NULL; job = next)
 	{
 	    next = job->jv_next;
-	    if (job->jv_status == JOB_STARTED && job->jv_exit_cb != NULL)
+	    if (job->jv_status == JOB_STARTED && job_still_useful(job))
 		job_status(job); /* may free "job" */
 	}
     }
@@ -4234,7 +4234,7 @@ job_stop_on_exit()
 
 /*
- * Called once in a while: check if any jobs with an "exit_cb" have ended.
+ * Called once in a while: check if any jobs that seem useful have ended.
  */
     void